This is a live mirror of the Perl 5 development currently hosted at https://github.com/perl/perl5
In Perl_pad_new(), avoid calling av_fetch() for something we already know.
[perl5.git] / parser.h
index 74d8ef2..e2769a7 100644 (file)
--- a/parser.h
+++ b/parser.h
@@ -15,7 +15,7 @@ typedef struct {
     YYSTYPE val;    /* semantic value */
     short   state;
     I32     savestack_ix;      /* size of savestack at this state */
-    AV     *comppad; /* value of PL_comppad when this value was created */
+    CV     *compcv; /* value of PL_compcv when this value was created */
 #ifdef DEBUGGING
     const char  *name; /* token/rule name for -Dpv */
 #endif
@@ -105,8 +105,16 @@ typedef struct yy_parser {
     COP                *saved_curcop;  /* the previous PL_curcop */
     char       tokenbuf[256];
 
+    bool       in_pod;         /* lexer is within a =pod section */
 } yy_parser;
 
+/* flags for lexer API */
+#define LEX_STUFF_UTF8         0x00000001
+#define LEX_KEEP_PREVIOUS      0x00000002
+
+/* flags for parser API */
+#define PARSE_OPTIONAL          0x00000001
+
 /*
  * Local variables:
  * c-indentation-style: bsd